@@ -1,4 +1,5 @@
 from agiflow.config.environment_vars import EnvironmentVars
+from agiflow.config.constants import API_ENDPOINT, SDK_NAME
 
 
 def is_tracing_enabled() -> bool:
@@ -14,8 +15,20 @@ def is_metrics_enabled() -> bool:
 
 
 def is_console_log_enabled() -> bool:
-    return EnvironmentVars.AGIFLOW_SUPPRESS_WARNINGS.lower() == "true"
+    return EnvironmentVars.AGIFLOW_SUPPRESS_WARNINGS.lower() == "false"
 
 
 def is_using_global_provider() -> bool:
     return EnvironmentVars.AGIFLOW_OTEL_PYTHON_TRACER_PROVIDER_GLOBAL.lower() == "true"
+
+
+__all__ = [
+  'EnvironmentVars',
+  'is_tracing_enabled',
+  'is_content_tracing_enabled',
+  'is_metrics_enabled',
+  'is_console_log_enabled',
+  'is_using_global_provider',
+  'API_ENDPOINT',
+  'SDK_NAME'
+]
