@@ -19,8 +19,8 @@ from agiflow.opentelemetry.convention.constants import (
   OpenAIMethods,
   ChromaDBMethods,
   PineconeMethods,
-  AgiflowSpanKindValues,
   AgiflowServiceTypes,
+  WeaviateMethods,
   LLMTypes,
   LLMPromptKeys,
   LLMPromptRoles,
@@ -30,14 +30,34 @@ from agiflow.opentelemetry.convention.constants import (
 
 
 class SpanAttributes(AgiflowSpanAttributes, LLMSpanAttributes, FrameworkSpanAttributes, DatabaseSpanAttributes):
+    """
+    All span attributes collected by Agiflow.
+    Using this for key value instead of hard coding to ensure
+    consistent telemetry schema.
+    """
     def __init__(self):
         super()
 
 
 __all__ = [
-  'LLMSpanAttributes', 'DatabaseSpanAttributes', 'FrameworkSpanAttributes', 'Event',
-  'OpenAIMethods', 'ChromaDBMethods', 'PineconeMethods', 'AgiflowSpanKindValues',
-  'FrameworkSpanAttributesValidator', 'DatabaseSpanAttributesValidator', 'LLMSpanAttributesValidator',
-  'AgiflowSpanAttributesValidator', 'AgiflowSpanAttributes', 'AgiflowServiceTypes', "LLMTypes",
-  "LLMPromptKeys", "LLMPromptRoles", "LLMResponseKeys", "LLMTokenUsageKeys", "SpanAttributes"
+  'LLMSpanAttributes',
+  'DatabaseSpanAttributes',
+  'FrameworkSpanAttributes',
+  'Event',
+  'OpenAIMethods',
+  'ChromaDBMethods',
+  'PineconeMethods',
+  'FrameworkSpanAttributesValidator',
+  'DatabaseSpanAttributesValidator',
+  'LLMSpanAttributesValidator',
+  'AgiflowSpanAttributesValidator',
+  'AgiflowSpanAttributes',
+  'AgiflowServiceTypes',
+  "LLMTypes",
+  "LLMPromptKeys",
+  "LLMPromptRoles",
+  "LLMResponseKeys",
+  "LLMTokenUsageKeys",
+  "SpanAttributes",
+  "WeaviateMethods",
   ]
