@@ -17,6 +17,7 @@ limitations under the License.
 import importlib.metadata
 
 from agiflow.opentelemetry.convention import SpanAttributes
+from agiflow.opentelemetry.convention.constants import AgiflowServiceTypes
 from agiflow.opentelemetry.instrumentation.constants.common import (
     SERVICE_PROVIDERS,
 )
@@ -34,5 +35,6 @@ class LangchainCommunitySpanCapture(BaseSpanCapture):
         service_provider = SERVICE_PROVIDERS["LANGCHAIN_COMMUNITY"]
         self.set_pydantic_attributes({
             SpanAttributes.AGIFLOW_SERVICE_NAME: service_provider,
-            SpanAttributes.AGIFLOW_SERVICE_VERSION: self.version,
+            SpanAttributes.AGIFLOW_SERVICE_VERSION: importlib.metadata.version("langchain-community"),
+            SpanAttributes.AGIFLOW_SERVICE_TYPE: AgiflowServiceTypes.FRAMEWORK,
         })
