@@ -16,6 +16,7 @@ limitations under the License.
 
 import importlib.metadata
 from agiflow.opentelemetry.convention import SpanAttributes
+from agiflow.opentelemetry.convention.constants import AgiflowServiceTypes
 from agiflow.opentelemetry.instrumentation.constants.common import (
     SERVICE_PROVIDERS,
 )
@@ -38,4 +39,5 @@ class LangchainCoreSpanCapture(BaseSpanCapture):
             SpanAttributes.AGIFLOW_SERVICE_NAME: service_provider,
             SpanAttributes.AGIFLOW_SERVICE_VERSION: importlib.metadata.version("langchain-core"),
             SpanAttributes.AGIFLOW_ENTITY_NAME: self.task,
+            SpanAttributes.AGIFLOW_SERVICE_TYPE: AgiflowServiceTypes.FRAMEWORK,
         })
