@@ -1 +1,5 @@
 from agiflow.opentelemetry.span_processors.thread_pool_span_processor import ThreadPoolSpanProcessor
+
+__all__ = [
+  'ThreadPoolSpanProcessor'
+]
