@@ -4,7 +4,11 @@ from opentelemetry.util.types import Attributes
 
 
 class NoSampler(Sampler):
-    """Alway trace span"""
+    """
+    Alway trace span.
+    Using this Sampler to consistently sending trace to Agiflow
+    to collect user feedback.
+    """
 
     def __init__(self):
         self._decision = 1
