@@ -1,4 +1,7 @@
 import json
+from agiflow.utils.debugging import Debugger
+
+debugger = Debugger(__name__)
 
 
 def clean_empty(d):
@@ -24,13 +27,25 @@ def custom_serializer(obj):
         return str(obj)
 
 
+def non_serialize(value):
+    return f"<<non-serializable: {type(value).__qualname__}>>"
+
+
 def serialise_to_json(value) -> str:
     cleaned_object = clean_empty(value)
     try:
-        return json.dumps(cleaned_object, default=custom_serializer)
+        return json.dumps(cleaned_object)
     except Exception as e:
-        print(e)
-        return value
+        debugger.warn(f"Failed to json.dump {str(e)}")
+        try:
+            return json.dumps(cleaned_object, default=custom_serializer)
+        except Exception as e:
+            debugger.warn(f"Failed to json.dump with custom_serializer {str(e)}")
+            try:
+                return json.dumps(cleaned_object, default=non_serialize)
+            except Exception as e:
+                debugger.warn(f"Failed to json.dump with non_serialize {str(e)}")
+                return value
 
 
 def cameltosnake(camel_string: str) -> str:
